<?php

namespace Drupal\Tests\google_calendar_service\Functional;

use Drupal\Tests\BrowserTestBase;

/**
 * Tests Google Calendar Service configuration.
 *
 * @group google_calendar_service
 */
class GoogleCalendarServiceTest extends BrowserTestBase {

  /**
   * Modules to enable.
   *
   * @var array<string>
   */
  protected static $modules = ['google_calendar_service'];

  /**
   * Theme to enable. This field is mandatory.
   *
   * @var string
   */
  protected $defaultTheme = 'stark';


  /**
   * A test user with permission to access google calendar service config page.
   *
   * @var \Drupal\user\UserInterface
   */
  protected $adminUser;

  /**
   * {@inheritdoc}
   */
  protected function setUp(): void {
    // Make sure to complete the normal setup steps first.
    parent::setUp();

    // Create and log in an administrative user.
    $this->adminUser = $this->drupalCreateUser([
      'administer calendars and events',
    ]);
    $this->drupalLogin($this->adminUser);
  }

  /**
   * The simplest assert possible.
   */
  public function testOne() {
    // Load the front page.
    $this->drupalGet('<front>');

    // Confirm that the site didn't throw a server error or something else.
    $this->assertSession()->statusCodeEquals(200);
  }

  /**
   * Test the admin page.
   */
  public function testAdminPage() {
    // Load the destination page.
    $this->drupalGet('admin/config/google-calendar-service/settings');
    $session = $this->assertSession();
    $session->statusCodeEquals(200);
    $session->pageTextContains('Secret Client File Step');
    $session->pageTextContains('Google User Email');
    $session->pageTextContains('Secret Client File');
    $session->fieldExists('google_user_email');
    $session->buttonExists('Save configuration');

    // Create a new source of type File Directory.
    $edit = [
      'google_user_email' => 'googletest@gmail.com',
    ];

    $this->submitForm($edit, 'Save configuration');
  }

}
